@@ -106,10 +106,11 @@ def _match_alike(expected, topic, diff=False):
 def _strip_string(text):
     if not text:
         return text
-
+    
+    text = utils.fix_string(text)
     text = REMOVE_COLORS_REGEX.sub('', text)
     text = _filter_str(text)
-    text = utils.fix_string(text)
+    
     return text
 
 
@@ -147,20 +148,13 @@ def _compare_datetime(expected, topic):
     return __timedelta_to_seconds(topic - expected) <= DATE_THRESHOLD
 
 
-def round_number(number, precision=2):
-    power = float(10 ^ precision)
-
-    return round(number * power, 0) / power
-
-
 def _compare_numbers(expected, topic):
     '''Asserts the "like"-ness of `topic` and `expected` as Numbers.'''
     FALSE_CONDITIONS = (not isinstance(topic, numbers.Number),
                         not isinstance(expected, numbers.Number), )
     if any(FALSE_CONDITIONS):
         return False
-
-    return round_number(float(expected)) == round_number(float(topic))
+    return float(expected) == float(topic)
 
 
 def _compare_dicts(expected, topic):
@@ -183,6 +177,8 @@ def _compare_lists(expected, topic):
 
 def _match_lists(expected, topic):
     '''Asserts the "like"-ness each item in of `topic` and `expected` (as lists or tuples).'''
+    # TODO: Rewrite this using itertools
+    #       http://docs.python.org/2/library/itertools.html
     for item in expected:
         if isinstance(item, (list, tuple)):
             found = False
@@ -210,7 +206,8 @@ def to_be_like(topic, expected, diff=True):
             is_str(topic) and
             is_str(expected)
         ):
-            matcher, first, second = compare(_strip_string(topic), _strip_string(expected))
+            first, second = _strip_string(topic), _strip_string(expected)
+            matcher, first, second = compare(first, second)
             print()
             print('Expected strings to be equal, but they were different:')
             print(first)
